@@ -286,8 +286,8 @@ func (a *APIClient) CheckConnectivity() bool {
 		}
 	}()
 
-	// Need reload to pick up any kubeconfig changes.
-	cfg, err := NewConfig(a.config.flags).RESTConfig()
+	cfg, err := a.config.RESTConfig()
+
 	if err != nil {
 		log.Error().Err(err).Msgf("restConfig load failed")
 		a.connOK = false
@@ -545,17 +545,19 @@ func (a *APIClient) SwitchContext(name string) error {
 	if err := a.config.SwitchContext(name); err != nil {
 		return err
 	}
-	if err := a.invalidateCache(); err != nil {
+
+	if !a.CheckConnectivity() {
+		log.Debug().Msg("No connectivity, skipping cache invalidation")
+	} else if err := a.invalidateCache(); err != nil {
 		return err
 	}
 	a.reset()
 	ResetMetrics()
 
-	if !a.CheckConnectivity() {
-		return fmt.Errorf("unable to connect to context %q", name)
-	}
+	// Need reload to pick up any kubeconfig changes.
+	a.config = NewConfig(a.config.flags)
 
-	return nil
+	return a.invalidateCache()
 }
 
 func (a *APIClient) reset() {
