@@ -4,7 +4,11 @@
 package mock
 
 import (
+	"errors"
 	"fmt"
+	"io/fs"
+	"net/http"
+	"net/url"
 	"os"
 	"strings"
 
@@ -21,7 +25,7 @@ import (
 )
 
 func EnsureDir(d string) error {
-	if _, err := os.Stat(d); os.IsNotExist(err) {
+	if _, err := os.Stat(d); errors.Is(err, fs.ErrNotExist) {
 		return os.MkdirAll(d, 0700)
 	}
 	if err := os.RemoveAll(d); err != nil {
@@ -104,6 +108,8 @@ func (m mockKubeSettings) ContextNames() (map[string]struct{}, error) {
 	return mm, nil
 }
 
+func (m mockKubeSettings) SetProxy(proxy func(*http.Request) (*url.URL, error)) {}
+
 type mockConnection struct {
 	ct string
 }
