@@ -23,7 +23,7 @@ type Context struct {
 }
 
 func (c *Context) config() *client.Config {
-	return c.GetFactory().Client().Config()
+	return c.getFactory().Client().Config()
 }
 
 // Get a Context.
@@ -60,5 +60,5 @@ func (c *Context) MustCurrentContextName() string {
 
 // Switch to another context.
 func (c *Context) Switch(ctx string) error {
-	return c.GetFactory().Client().SwitchContext(ctx)
+	return c.getFactory().Client().SwitchContext(ctx)
 }
