@@ -31,7 +31,7 @@ type LogsListener interface {
 	// LogStop indicates logging was canceled.
 	LogStop()
 
-	// LogResume indicates loggings has resumed.
+	// LogResume indicates logging has resumed.
 	LogResume()
 
 	// LogCanceled indicates no more logs will come.
@@ -108,7 +108,7 @@ func (l *Log) SetSinceSeconds(ctx context.Context, i int64) {
 }
 
 // Configure sets logger configuration.
-func (l *Log) Configure(opts *config.Logger) {
+func (l *Log) Configure(opts config.Logger) {
 	l.logOptions.Lines = int64(opts.TailCount)
 	l.logOptions.SinceSeconds = opts.SinceSeconds
 }
