@@ -12,11 +12,11 @@ import (
 )
 
 func TestKeyActionsHints(t *testing.T) {
-	kk := ui.KeyActions{
+	kk := ui.NewKeyActionsFromMap(ui.KeyMap{
 		ui.KeyF: ui.NewKeyAction("fred", nil, true),
 		ui.KeyB: ui.NewKeyAction("blee", nil, true),
 		ui.KeyZ: ui.NewKeyAction("zorg", nil, false),
-	}
+	})
 
 	hh := kk.Hints()
 
