@@ -7,6 +7,7 @@ import (
 	"context"
 	"time"
 
+	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/model1"
@@ -75,4 +76,7 @@ type Tabular interface {
 
 	// Delete a resource.
 	Delete(context.Context, string, *metav1.DeletionPropagation, dao.Grace) error
+
+	// SetViewSetting injects custom cols specification.
+	SetViewSetting(context.Context, *config.ViewSetting)
 }
