@@ -67,7 +67,7 @@ func (a *Alias) gotoCmd(evt *tcell.EventKey) *tcell.EventKey {
 	if r != 0 {
 		s := ui.TrimCell(a.GetTable().SelectTable, r, 1)
 		tokens := strings.Split(s, ",")
-		a.App().gotoResource(tokens[0], "", true)
+		a.App().gotoResource(tokens[0], "", true, true)
 		return nil
 	}
 
