@@ -11,8 +11,10 @@ import (
 )
 
 func ToLabels(s string) map[string]string {
-	ll := strings.Split(s, ",")
-	lbls := make(map[string]string, len(ll))
+	var (
+		ll   = strings.Split(s, ",")
+		lbls = make(map[string]string, len(ll))
+	)
 	for _, l := range ll {
 		kv := strings.Split(l, "=")
 		if len(kv) < 2 || kv[0] == "" || kv[1] == "" {
@@ -20,7 +22,6 @@ func ToLabels(s string) map[string]string {
 		}
 		lbls[kv[0]] = kv[1]
 	}
-
 	if len(lbls) == 0 {
 		return nil
 	}
@@ -112,6 +113,10 @@ func completeCtx(s string, cc []string) []string {
 	var suggests []string
 	for _, ctxName := range cc {
 		if suggest, ok := ShouldAddSuggest(s, ctxName); ok {
+			if len(s) == 0 {
+				suggests = append(suggests, " "+suggest)
+				continue
+			}
 			suggests = append(suggests, suggest)
 		}
 	}
