@@ -4,9 +4,12 @@
 package view
 
 import (
+	"errors"
+
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/ui"
+	appsv1 "k8s.io/api/apps/v1"
 )
 
 // DaemonSet represents a daemon set custom viewer.
@@ -16,17 +19,18 @@ type DaemonSet struct {
 
 // NewDaemonSet returns a new viewer.
 func NewDaemonSet(gvr client.GVR) ResourceViewer {
-	d := DaemonSet{
-		ResourceViewer: NewPortForwardExtender(
-			NewVulnerabilityExtender(
-				NewRestartExtender(
-					NewImageExtender(
-						NewLogsExtender(NewBrowser(gvr), nil),
+	var d DaemonSet
+	d.ResourceViewer = NewPortForwardExtender(
+		NewVulnerabilityExtender(
+			NewRestartExtender(
+				NewImageExtender(
+					NewOwnerExtender(
+						NewLogsExtender(NewBrowser(gvr), d.logOptions),
 					),
 				),
 			),
 		),
-	}
+	)
 	d.AddBindKeysFn(d.bindKeys)
 	d.GetTable().SetEnterFn(d.showPods)
 
@@ -55,3 +59,23 @@ func (d *DaemonSet) showPods(app *App, model ui.Tabular, _ client.GVR, path stri
 
 	showPodsFromSelector(app, path, ds.Spec.Selector)
 }
+
+func (d *DaemonSet) logOptions(prev bool) (*dao.LogOptions, error) {
+	path := d.GetTable().GetSelectedItem()
+	if path == "" {
+		return nil, errors.New("you must provide a selection")
+	}
+	ds, err := d.getInstance(path)
+	if err != nil {
+		return nil, err
+	}
+
+	return podLogOptions(d.App(), path, prev, ds.ObjectMeta, ds.Spec.Template.Spec), nil
+}
+
+func (d *DaemonSet) getInstance(fqn string) (*appsv1.DaemonSet, error) {
+	var ds dao.DaemonSet
+	ds.Init(d.App().factory, client.NewGVR("apps/v1/daemonsets"))
+
+	return ds.GetInstance(fqn)
+}
