@@ -95,11 +95,11 @@ func (s *ImageExtender) showImageDialog(path string) error {
 }
 
 func (s *ImageExtender) makeSetImageForm(sel string) (*tview.Form, error) {
-	f := s.makeStyledForm()
 	podSpec, err := s.getPodSpec(sel)
 	if err != nil {
 		return nil, err
 	}
+
 	formContainerLines := make([]*imageFormSpec, 0, len(podSpec.InitContainers)+len(podSpec.Containers))
 	for _, spec := range podSpec.InitContainers {
 		formContainerLines = append(formContainerLines, &imageFormSpec{init: true, name: spec.Name, dockerImage: spec.Image})
@@ -107,6 +107,36 @@ func (s *ImageExtender) makeSetImageForm(sel string) (*tview.Form, error) {
 	for _, spec := range podSpec.Containers {
 		formContainerLines = append(formContainerLines, &imageFormSpec{name: spec.Name, dockerImage: spec.Image})
 	}
+
+	styles := s.App().Styles.Dialog()
+	f := tview.NewForm().
+		SetItemPadding(0).
+		SetButtonsAlign(tview.AlignCenter).
+		SetButtonBackgroundColor(styles.ButtonBgColor.Color()).
+		SetButtonTextColor(styles.ButtonFgColor.Color()).
+		SetLabelColor(styles.LabelFgColor.Color()).
+		SetFieldTextColor(styles.FieldFgColor.Color()).
+		AddButton("OK", func() {
+			defer s.dismissDialog()
+			var imageSpecsModified dao.ImageSpecs
+			for _, v := range formContainerLines {
+				if v.modified() {
+					imageSpecsModified = append(imageSpecsModified, v.imageSpec())
+				}
+			}
+			ctx, cancel := context.WithTimeout(context.Background(), s.App().Conn().Config().CallTimeout())
+			defer cancel()
+			if err := s.setImages(ctx, sel, imageSpecsModified); err != nil {
+				log.Error().Err(err).Msgf("PodSpec %s image update failed", sel)
+				s.App().Flash().Err(err)
+				return
+			}
+			s.App().Flash().Infof("Resource %s:%s image updated successfully", s.GVR(), sel)
+		}).
+		AddButton("Cancel", func() {
+			s.dismissDialog()
+		})
+
 	for i := range formContainerLines {
 		ctn := formContainerLines[i]
 		f.AddInputField(ctn.name, ctn.dockerImage, 0, nil, func(changed string) {
@@ -114,26 +144,11 @@ func (s *ImageExtender) makeSetImageForm(sel string) (*tview.Form, error) {
 		})
 	}
 
-	f.AddButton("OK", func() {
-		defer s.dismissDialog()
-		var imageSpecsModified dao.ImageSpecs
-		for _, v := range formContainerLines {
-			if v.modified() {
-				imageSpecsModified = append(imageSpecsModified, v.imageSpec())
-			}
-		}
-		ctx, cancel := context.WithTimeout(context.Background(), s.App().Conn().Config().CallTimeout())
-		defer cancel()
-		if err := s.setImages(ctx, sel, imageSpecsModified); err != nil {
-			log.Error().Err(err).Msgf("PodSpec %s image update failed", sel)
-			s.App().Flash().Err(err)
-			return
-		}
-		s.App().Flash().Infof("Resource %s:%s image updated successfully", s.GVR(), sel)
-	})
-	f.AddButton("Cancel", func() {
-		s.dismissDialog()
-	})
+	for i := 0; i < f.GetButtonCount(); i++ {
+		f.GetButton(i).
+			SetBackgroundColorActivated(styles.ButtonFocusBgColor.Color()).
+			SetLabelColorActivated(styles.ButtonFocusFgColor.Color())
+	}
 
 	return f, nil
 }
@@ -142,17 +157,6 @@ func (s *ImageExtender) dismissDialog() {
 	s.App().Content.RemovePage(imageKey)
 }
 
-func (s *ImageExtender) makeStyledForm() *tview.Form {
-	f := tview.NewForm()
-	f.SetItemPadding(0)
-	f.SetButtonsAlign(tview.AlignCenter).
-		SetButtonBackgroundColor(tview.Styles.PrimitiveBackgroundColor).
-		SetButtonTextColor(tview.Styles.PrimaryTextColor).
-		SetLabelColor(tcell.ColorAqua).
-		SetFieldTextColor(tcell.ColorOrange)
-	return f
-}
-
 func (s *ImageExtender) getPodSpec(path string) (*corev1.PodSpec, error) {
 	res, err := dao.AccessorFor(s.App().factory, s.GVR())
 	if err != nil {
