@@ -64,7 +64,7 @@ type Pulse struct {
 	gvr      client.GVR
 	model    *model.Pulse
 	cancelFn context.CancelFunc
-	actions  ui.KeyActions
+	actions  *ui.KeyActions
 	charts   []Graphable
 }
 
@@ -73,7 +73,7 @@ func NewPulse(gvr client.GVR) ResourceViewer {
 	return &Pulse{
 		Grid:    tview.NewGrid(),
 		model:   model.NewPulse(gvr.String()),
-		actions: make(ui.KeyActions),
+		actions: ui.NewKeyActions(),
 	}
 }
 
@@ -207,15 +207,15 @@ func (p *Pulse) PulseFailed(err error) {
 }
 
 func (p *Pulse) bindKeys() {
-	p.actions.Add(ui.KeyActions{
+	p.actions.Merge(ui.NewKeyActionsFromMap(ui.KeyMap{
 		tcell.KeyEnter:   ui.NewKeyAction("Goto", p.enterCmd, true),
 		tcell.KeyTab:     ui.NewKeyAction("Next", p.nextFocusCmd(1), true),
 		tcell.KeyBacktab: ui.NewKeyAction("Prev", p.nextFocusCmd(-1), true),
-	})
+	}))
 
 	for i, v := range p.charts {
 		t := cases.Title(language.Und, cases.NoLower).String(client.NewGVR(v.ID()).R())
-		p.actions[ui.NumKeys[i]] = ui.NewKeyAction(t, p.sparkFocusCmd(i), true)
+		p.actions.Add(ui.NumKeys[i], ui.NewKeyAction(t, p.sparkFocusCmd(i), true))
 	}
 }
 
@@ -224,7 +224,7 @@ func (p *Pulse) keyboard(evt *tcell.EventKey) *tcell.EventKey {
 	if key == tcell.KeyRune {
 		key = tcell.Key(evt.Rune())
 	}
-	if a, ok := p.actions[key]; ok {
+	if a, ok := p.actions.Get(key); ok {
 		return a.Action(evt)
 	}
 
@@ -289,7 +289,7 @@ func (p *Pulse) GetTable() *Table {
 }
 
 // Actions returns active menu bindings.
-func (p *Pulse) Actions() ui.KeyActions {
+func (p *Pulse) Actions() *ui.KeyActions {
 	return p.actions
 }
 
@@ -320,7 +320,7 @@ func (p *Pulse) enterCmd(evt *tcell.EventKey) *tcell.EventKey {
 	if res == "cpu" || res == "mem" {
 		res = "pod"
 	}
-	p.App().gotoResource(res+" all", "", false)
+	p.App().gotoResource(res+" all", "", false, true)
 
 	return nil
 }
