@@ -35,7 +35,7 @@ func NewScreenDump(gvr client.GVR) ResourceViewer {
 }
 
 func (s *ScreenDump) dirContext(ctx context.Context) context.Context {
-	dir := s.App().Config.K9s.ActiveScreenDumpsDir()
+	dir := s.App().Config.K9s.ContextScreenDumpDir()
 	if err := data.EnsureFullPath(dir, data.DefaultDirMod); err != nil {
 		s.App().Flash().Err(err)
 		return ctx
